operators
=========
.. automodule:: tike.operators
   :no-members:

.. automodule:: tike.operators.cupy
   :inherited-members:
   :members:
   :show-inheritance:
   :undoc-members:

   .. autosummary::
      :nosignatures:

      Operator
      Alignment
      CachedFFT
      Convolution
      Flow
      Lamino
      Pad
      Propagation
      Ptycho
      Rotate
      Shift
